#ifdef ARDUINO_ARCH_ESP32
#include <WiFi.h>
#else
#include <ESP8266WiFi.h>
#endif
#include <Espalexa.h>
#include <FastLED.h>
#define LED_PIN D2
#define NUM_LEDS 10

CRGB leds[NUM_LEDS];
boolean connectWifi();

void firstLightChanged(uint8_t brightness);

const char* ssid = "****";
const char* password = "****";

boolean wifiConnected = false;
int state = 0;

Espalexa espalexa;

void setup()
{
  pinMode(LED_BUILTIN, OUTPUT);
  digitalWrite(LED_BUILTIN, HIGH); 
  FastLED.addLeds<WS2812, LED_PIN, GRB>(leds, NUM_LEDS);
  FastLED.setMaxPowerInVoltsAndMilliamps(5, 500);
  FastLED.clear();
  for (int i = 0; i < NUM_LEDS; i++ )
    leds[i] = CRGB::Black;
  FastLED.show();

  Serial.begin(115200);
  wifiConnected = connectWifi();

  if (wifiConnected) {
    espalexa.addDevice("Test Light", firstLightChanged);
    espalexa.begin();
  } 
  else
  {
    while (1) {
      Serial.println("Cannot connect to WiFi");
      delay(2500);
    }
  }
}

void loop()
{
  espalexa.loop();
  if (state == 1)
  {
    uint8_t thisSpeed = 10;
    uint8_t deltaHue= 10;
    uint8_t thisHue = beat8(thisSpeed,255); 
    fill_rainbow(leds, NUM_LEDS, thisHue, deltaHue); 
    FastLED.show();
  }
  else {
    Serial.println("OFF");
    for (int i = 0; i < NUM_LEDS; i++ )
      leds[i] = CRGB::Black;
    FastLED.show();
  }
  delay(1);
}


void firstLightChanged(uint8_t brightness) {
  Serial.print("Device 1 changed to ");
  if (brightness) {
    state = 1;
  }
  else  {
    state = 0;
  }
}

boolean connectWifi() {
  boolean state = true;
  int i = 0;

  WiFi.mode(WIFI_STA);
  WiFi.begin(ssid, password);
  Serial.println("");
  Serial.println("Connecting to WiFi");

  // Wait for connection
  Serial.print("Connecting...");
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
    if (i > 20) {
      state = false; break;
    }
    i++;
  }
  Serial.println("");
  if (state) {
    Serial.print("Connected to ");
    Serial.println(ssid);
    Serial.print("IP address: ");
    Serial.println(WiFi.localIP());
  }
  else {
    Serial.println("Connection failed.");
  }
  return state;
}
